==> aws-cdk.aws-eventschemas-1.135.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_eventschemas_CfnRegistryPolicyProps(p) {
}
function _aws_cdk_aws_eventschemas_CfnRegistryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        _aws_cdk_aws_eventschemas_CfnRegistry_TagsEntryProperty(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_eventschemas_CfnSchemaProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        _aws_cdk_aws_eventschemas_CfnSchema_TagsEntryProperty(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_eventschemas_CfnDiscovererProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        _aws_cdk_aws_eventschemas_CfnDiscoverer_TagsEntryProperty(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_eventschemas_CfnRegistryPolicy(p) {
}
function _aws_cdk_aws_eventschemas_CfnRegistry(p) {
}
function _aws_cdk_aws_eventschemas_CfnRegistry_TagsEntryProperty(p) {
}
function _aws_cdk_aws_eventschemas_CfnSchema(p) {
}
function _aws_cdk_aws_eventschemas_CfnSchema_TagsEntryProperty(p) {
}
function _aws_cdk_aws_eventschemas_CfnDiscoverer(p) {
}
function _aws_cdk_aws_eventschemas_CfnDiscoverer_TagsEntryProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_eventschemas_CfnRegistryPolicyProps, _aws_cdk_aws_eventschemas_CfnRegistryProps, _aws_cdk_aws_eventschemas_CfnSchemaProps, _aws_cdk_aws_eventschemas_CfnDiscovererProps, _aws_cdk_aws_eventschemas_CfnRegistryPolicy, _aws_cdk_aws_eventschemas_CfnRegistry, _aws_cdk_aws_eventschemas_CfnRegistry_TagsEntryProperty, _aws_cdk_aws_eventschemas_CfnSchema, _aws_cdk_aws_eventschemas_CfnSchema_TagsEntryProperty, _aws_cdk_aws_eventschemas_CfnDiscoverer, _aws_cdk_aws_eventschemas_CfnDiscoverer_TagsEntryProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-eventschemas-1.152.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_eventschemas_CfnRegistryPolicyProps(p) {
}
function _aws_cdk_aws_eventschemas_CfnRegistryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        _aws_cdk_aws_eventschemas_CfnRegistry_TagsEntryProperty(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_eventschemas_CfnSchemaProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        _aws_cdk_aws_eventschemas_CfnSchema_TagsEntryProperty(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_eventschemas_CfnDiscovererProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        _aws_cdk_aws_eventschemas_CfnDiscoverer_TagsEntryProperty(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_eventschemas_CfnRegistryPolicy(p) {
}
function _aws_cdk_aws_eventschemas_CfnSchema(p) {
}
function _aws_cdk_aws_eventschemas_CfnSchema_TagsEntryProperty(p) {
}
function _aws_cdk_aws_eventschemas_CfnRegistry(p) {
}
function _aws_cdk_aws_eventschemas_CfnRegistry_TagsEntryProperty(p) {
}
function _aws_cdk_aws_eventschemas_CfnDiscoverer(p) {
}
function _aws_cdk_aws_eventschemas_CfnDiscoverer_TagsEntryProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_eventschemas_CfnRegistryPolicyProps, _aws_cdk_aws_eventschemas_CfnRegistryProps, _aws_cdk_aws_eventschemas_CfnSchemaProps, _aws_cdk_aws_eventschemas_CfnDiscovererProps, _aws_cdk_aws_eventschemas_CfnRegistryPolicy, _aws_cdk_aws_eventschemas_CfnSchema, _aws_cdk_aws_eventschemas_CfnSchema_TagsEntryProperty, _aws_cdk_aws_eventschemas_CfnRegistry, _aws_cdk_aws_eventschemas_CfnRegistry_TagsEntryProperty, _aws_cdk_aws_eventschemas_CfnDiscoverer, _aws_cdk_aws_eventschemas_CfnDiscoverer_TagsEntryProperty };
module.exports.DeprecationError = DeprecationError;
